@@ -3,7 +3,6 @@
 use crate::result::MapmErr;
 use crate::result::MapmErr::*;
 use crate::result::MapmResult;
-use crate::result::MapmResult::*;
 
 use crate::template::Template;
 use Filter::*;
@@ -73,7 +72,7 @@ pub fn fetch_problem(problem_name: &str, problem_dir: &Path) -> MapmResult<Probl
     let problem_src = &problem_dir.join(&[problem_name, ".yml"].concat());
     match fs::read_to_string(problem_src) {
         Ok(problem_yaml) => parse_problem_yaml(&problem_yaml),
-        Err(_) => Fail(ProblemErr(format!(
+        Err(_) => Err(ProblemErr(format!(
             "Could not read problem `{}` from {:?}",
             problem_name, problem_src
         ))),
@@ -422,7 +421,7 @@ pub fn parse_problem_yaml(yaml: &str) -> MapmResult<Problem> {
                         };
                     }
                     _ => {
-                        return Fail(ProblemErr(["Could not parse key `", &key, "`"].concat()));
+                        return Err(ProblemErr(["Could not parse key `", &key, "`"].concat()));
                     }
                 }
             }
@@ -432,10 +431,10 @@ pub fn parse_problem_yaml(yaml: &str) -> MapmResult<Problem> {
                 None => Vec::new(),
             };
 
-            return Success(Problem { vars, solutions });
+            return Ok(Problem { vars, solutions });
         }
         Err(err) => {
-            return Fail(ProblemErr(err.to_string()));
+            return Err(ProblemErr(err.to_string()));
         }
     }
 }
