@@ -2,7 +2,6 @@ use std::collections::HashMap;
 
 use crate::result::MapmErr::*;
 use crate::result::MapmResult;
-use crate::result::MapmResult::*;
 
 use std::fs;
 use std::path::Path;
@@ -25,7 +24,7 @@ pub fn fetch_template_config(template_name: &str, templates_dir: &Path) -> MapmR
     let template_path = &templates_dir.join(template_name).join("config.yml");
     match fs::read_to_string(template_path) {
         Ok(template_yaml) => parse_template_yaml(&template_yaml),
-        Err(_) => Fail(TemplateErr(format!(
+        Err(_) => Err(TemplateErr(format!(
             "Could not read template `{}` from {:?}",
             template_name, template_path,
         ))),
@@ -71,7 +70,7 @@ pub fn fetch_template_config(template_name: &str, templates_dir: &Path) -> MapmR
 
 pub fn parse_template_yaml(yaml: &str) -> MapmResult<Template> {
     match serde_yaml::from_str::<Template>(yaml) {
-        Ok(template) => Success(template),
-        Err(err) => Fail(TemplateErr(err.to_string())),
+        Ok(template) => Ok(template),
+        Err(err) => Err(TemplateErr(err.to_string())),
     }
 }
